@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Update;
 BEGIN {
-  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.09';
+  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.10';
 }
 
 use Moose;
@@ -24,13 +24,19 @@ has 'p3rl' => (
 	default => 0
 );
 
+has 'metacpan' => (
+	is   	=> 'ro',
+	isa  	=> 'Bool',
+	default => 0
+);
+
 =head1 NAME
 
 Dist::Zilla::Plugin::GitHub::Update - Update GitHub repo info on release
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -72,11 +78,17 @@ sub release {
 	push my @params, "login=$login", "token=$token",
 			'values[description]='.$self -> zilla -> abstract;
 
-	if ($self -> p3rl == 1) {
+	if ($self -> metacpan == 1) {
+		$self -> log("Using MetaCPAN URL");
+		push @params, "values[homepage]=http://metacpan.org/release/$repo_name/"
+	} elsif ($self -> p3rl == 1) {
 		my $guess_name = $repo_name;
 		$guess_name =~ s/\-/\:\:/g;
+
+		$self -> log("Using P3rl URL");
 		push @params, "values[homepage]=http://p3rl.org/$guess_name"
 	} elsif ($self -> cpan == 1) {
+		$self -> log("Using CPAN URL");
 		push @params, "values[homepage]=http://search.cpan.org/dist/$repo_name/"
 	}
 
@@ -112,6 +124,13 @@ p3rl.org shortened URL (e.g. C<http://p3rl.org/My::Module>).
 This takes precedence over the C<cpan> option (if both '1', p3rl will
 be used).
 
+=item C<metacpan>
+
+If set to '1' (default '0'), the GitHub homepage field will be set to the
+metacpan.org distribution URL (e.g. C<http://metacpan.org/release/My-Module>).
+This takes precedence over the C<cpan> and C<p3rl> options (if all three '1',
+metacpan will be used).
+
 =back
 
 =head1 AUTHOR
